%	find_skip		MATLAB function
%
%  finds the latest start time amongst nstat stations, start times are in 
%  structure head. Returns the number of samples to skip in each of the
%  data files so that data of all sites is aligned at start time of
%  latest site.

function [min_skip,max_skip,i_tmax,i_tmin] = find_skip(s)

  months = [31 28 31 30 31 30 31 31 30 31 30 31];
  nstat = length(s);

  % max sampling rate needed to find minskip
  max_dt = max([s.dt]);
  % estimate which data stream starts later
  
  for k = 1:nstat
    if (mod(s(1).start_year,100) ~= mod(s(k).start_year,100))
      error('YEAR of START TIME different. EXITING');
    end
    t_start(k) = s(k).start_sec+(60*(s(k).start_min+60*(s(k).start_hr+ ...
        (24*(s(k).start_day+sum(months(1:s(k).start_mon-1)))))));
  end
  % find index of maximum start time t
  i_tmax = min(find(t_start == max(t_start)));
  % make sure that this is a sample time of max_dt (i.e. the maximal 
  % sample interval)
  if (mod(t_start(i_tmax),max_dt)~=0) 
      t_start(i_tmax) = (floor(t_start(i_tmax)/max_dt)+1)*max_dt; 
  end
  min_skip = t_start(i_tmax) - t_start;
  
  % estimate which data stream ends earlier
  % right below: strange corrections - stop_day should be .ne. 0!
  for k = 1:nstat
    if (s(k).stop_day == 0 & (s(k).stop_hr < s(k).start_hr)) 
       s(k).stop_day = s(k).start_day + 1;
       s(k).stop_mon = s(k).start_mon;
       s(k).stop_year = s(k).start_year ;
       if (s(k).stop_day > months(s(k).start_mon))
             s(k).stop_day = 1;
             s(k).stop_mon = s(k).start_mon + 1;
       end
    elseif (s(k).stop_day == 0 & (s(k).stop_hr >= s(k).start_hr))
       s(k).stop_day = s(k).start_day;
       s(k).stop_mon = s(k).start_mon;
       s(k).stop_year = s(k).start_year;
    end
    if (mod(s(1).stop_year,100) ~= mod(s(k).stop_year,100))
      error('YEAR of STOP TIME different. EXITING');
    elseif (mod(s(k).start_year,100) ~= mod(s(k).stop_year,100))
      error('Recording over New Year. EXITING');
    end

    t_stop(k) = s(k).stop_sec+(60*(s(k).stop_min+60*(s(k).stop_hr+ ...
        (24*(s(k).stop_day+sum(months(1:s(k).stop_mon-1)))))));
  end
  % find index of maximum start time t
  i_tmin = min(find(t_stop == min(t_stop)));
  max_skip = t_stop(i_tmin)-t_start(i_tmax) + min_skip;
  if (t_stop(i_tmin) < t_start(i_tmax))
     error('Recordings do not overlap. EXISTING');
  end
  
return  
